@@ -34,9 +34,9 @@ $HAVEIM = 0;
 $HAVELJ = 0;
 ############################################################################
 
-# This is IGAL version 2.0, an online Image GALlery generator.
+# This is IGAL version 2.1, an online Image GALlery generator.
 #   Copyright (C) 2000 Eric Pop, 2003 Wolfgang Trexler
-#   This version was enhanced by Wolfgang Trexler (wt) Apr. 2003 - Nov. 2008
+#   This version was enhanced by Wolfgang Trexler (wt) Apr. 2003 - May 2012
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -54,16 +54,18 @@ $HAVELJ = 0;
 #
 # Author: Eric Pop, Dept. of Electrical Engineering, Stanford University
 # Email: epop@stanford.edu
-# Enhancements were done by: Wolfgang Trexler, Austria
+# Enhancements were done by: Wolfgang Trexler, Alexander Zangerl
 # EMail: wt-igal@trexler.at
 
 use FileHandle;
 use Getopt::Long;
 use POSIX qw(ceil floor);
+# Check if EXIF Tool library is installed
+$ExifTool = eval "use Image::ExifTool; 1" ? 1 : 0;
 
 
 # some constants
-$VERSION = "2.0";
+$VERSION = "2.1";
 $Getopt::Long::ignorecase = 0;
 $itile = "tile.png";
 $slidetemplate = "slidetemplate2.html";
@@ -82,6 +84,7 @@ $opt_a = "0";          # to write image size under thumbnails in index page
 $opt_c = "0";          # -c to use user-supplied captions
 $opt_C = "0";          # same as -c, but preserve image names as captions
 $opt_d = ".";          # look in current directory "."
+$opt_e = "0";          # write EXIF information under image
 $opt_f = "0";          # -f to force thumbnail regeneration
 $opt_h = "0";
 $opt_i = "index.html"; # name of the main thumbnail index file
@@ -115,6 +118,7 @@ Options:     -a           write image sizes under thumbnails on index page
              -c           first generate and then use captions
              -C           like -c, but preserve file names as captions
              -d <dir>     operate on files in directory <dir> (.)
+             -e           write EXIF information under image (needs Image::ExifTool)
              -f           force thumbnail regeneration
              -h           displays this brief help; same as --help
              -i <file>    name of the main thumbnail index file (index.html)
@@ -165,7 +169,8 @@ Note:         default values are given in parentheses (where applicable).
 Authors:      Wolfgang Trexler <wt-igal\@trexler.at>
               Eric Pop <epop\@stanford.edu> (original igal)
 	      contributions: 
-              Stewart Addison <contactsxa\@gmail.com>, Riku Kalinen
+              Stewart Addison <contactsxa\@gmail.com>, Riku Kalinen,
+              Alexander Zangerl
 URL:          http://igal.trexler.at/
 END_OF_USAGE
 
@@ -173,7 +178,7 @@ END_OF_USAGE
 @igal_options = @ARGV;
 
 # process command-line arguments (overriding defaults above)
-GetOptions('a','c','C','d=s','f','h','i=s','k','m=s','n','o=s',
+GetOptions('a','c','C','d=s','e','f','h','i=s','k','m=s','n','o=s',
            'p=i','r','s','t=i','u','w=i','x','y=i','ad','as',
            'bigy=i', 'con=s','help','im','www','xy=i', 'dest=s', 
 	   'AddSubdir', 'pagination=s') or die "$usage";
@@ -194,6 +199,8 @@ die "Please enter a nonnegative tiled image height\n" if ($opt_t < 0);
 die "Please enter a nonnegative pagination value\n" if ($opt_pagination < 0);
 $opt_o = "$opt_o/" if ( $opt_o );
 
+die "Critical failure: Lib Image::ExifTool not install but EXIF Tags (option -e) requested\n" if (($ExifTool == 0) and ($opt_e));
+ 
 # strip any unnecessary slashes from the end of the given $opt_d directory
 $opt_d =~ s/\/$//;
 
@@ -544,6 +551,20 @@ if ($opt_s) {
 		}
 		$workarea =~ s/<!--IMAGE-CAPTION-->/$imagecaption/g;
 
+		# add EXIF information if -e is specified 
+		if ($opt_e) {
+		    my $exif=Image::ExifTool::ImageInfo($imgfiles[$i]);
+		    my $exifinfo= "<A href=\"javascript:toggle('exifinfo');\">Show/hide EXIF data</A>\n";
+		    $exifinfo .= "<DIV id=\"exifinfo\">\n";
+		    $exifinfo .= "<TABLE><th>EXIF Tag</th><th>Value</th>\n";
+		    for my $k (sort keys %$exif) {
+			$exifinfo .= "<TR><TD>$k</TD><TD>".
+			    (ref($exif->{$k}) eq "SCALAR"?'Binary data '.length(${$exif->{$k}}).' bytes':$exif->{$k})."</TD></TR>\n";
+		    }
+		    $exifinfo .= "</TABLE></DIV>\n";
+		    $workarea =~ s/<!--EXIF-INFO-->/$exifinfo/g;
+                }
+
 		# find out if pagination is used and which number the index file has...
 		$index_file_number = ($opt_pagination) ? int ($i / $opt_pagination) : 0;
 		$index_filename = ($index_file_number == 0) ? $opt_i : "$index_file_number$opt_i";
